""" Base scene class. """

from pygame.sprite import RenderUpdates
from ..cursor import Cursor


class BaseScene(object):
    def __init__(self):
        self._cursor = Cursor()
        self._cursor_group = RenderUpdates()

    def _set_cursor(self, name, transform=None):
        self._cursor.activate(name, self._cursor_group, transform=transform)

    def _unset_cursor(self):
        self._cursor.deactivate(self._cursor_group)

    def _draw_cursor(self, surface):
        """Draw the cursor. Should be called at the end of the render
           method by scenes that need it."""
        self._cursor_group.update()
        self._cursor_group.draw(surface)

    def enter(self, gamestate):
        """ Enter the scene. """

    def exit(self, gamestate):
        """ Leave the scene. """

    def event(self, ev, gamestate):
        """ Handle an event. """

    def render(self, screen, gamestate):
        """ Render the scene. """

    def tick(self, gamestate):
        """ Update the world based on time """
